require("lazy").setup({
	{ "nvim-lua/plenary.nvim" },
	{
		"ray-x/guihua.lua",
		build = "cd lua/fzy && make",
	},
	{ "neovim/nvim-lspconfig" },
	{
		"lukas-reineke/indent-blankline.nvim",
		main = "ibl",
		--@module "ibl"
		--@type ibl.config
		config = true,
	},
	{
		"lukas-reineke/headlines.nvim",
		dependencies = "nvim-treesitter/nvim-treesitter",
		config = true,
	},
	{
		"mfussenegger/nvim-dap",
	},
	{
		"ray-x/lsp_signature.nvim",
		event = "VeryLazy",
		opts = {
			doc_lines = 1,
			max_height = 3,
			hint_prefix = "",
			hint_prefix = {
				above = "↙ ",
				current = "← ",
				below = "↖ ",
			},
			floating_window = true,
		},
	},
	{
		"nvimdev/lspsaga.nvim",
		opts = {
			lightbulb = {
				enable = false,
			},
		},
	},
	{
		"karb94/neoscroll.nvim",
		opts = {
			stop_eof = false,
			respect_scrolloff = true,
			mappings = {
				"<C-u>",
				"<C-d>",
				"<C-b>",
				"<C-f>",
				"<C-y>",
				"<C-e>",
				"zt",
				"zz",
				"zb",
			},
		},
		keys = {
			{
				"<PageUp>",
				function()
					require("neoscroll").scroll(-vim.api.nvim_win_get_height(0) + 3, { duration = 150 })
				end,
			},
			{
				"<PageDown>",
				function()
					require("neoscroll").scroll(vim.api.nvim_win_get_height(0) - 3, { duration = 150 })
				end,
			},
		},
	},
	require("plugins.autosave"),
	require("plugins.cmp"),
	require("plugins.treesitter"),
	require("plugins.tree"),
	require("plugins.conform"),
	require("plugins.dapui"),
	require("plugins.dap"),
	require("plugins.go"),
	require("plugins.goimpl"),
	require("plugins.lualine"),
	require("plugins.telescope"),
	require("plugins.columns"),
}, {
	performance = {
		rtp = {
			disabled_plugins = {
				"gzip",
				"matchit",
				"matchparen",
				"netrwPlugin",
				"tarPlugin",
				"tohtml",
				"tutor",
				"zipPlugin",
			},
		},
	},
})
